package Bundle::Pugs::SmokeKit;

$Bundle::Pugs::SmokeKit::VERSION = '1.00';

-1;
__END__

=head1 NAME

Bundle::Pugs::SmokeKit - Bundle for running Pugs smoke tests

=head1 SYNOPSIS

  ### This bundle is obsoleted in favor of Task::Smoke. ###
  
  perl -MCPAN -e 'install Task::Smoke'

=head1 CONTENTS

Task::Smoke

=head1 DESCRIPTION

B<This module has been obsoleted by Task::Smoke. Please install that instead.>

=head1 SEE ALSO

L<Taslk::Smoke>, L<Perl6::Pugs>, L<http://smoke.pugscode.org/>

=head1 AUTHOR

Gaal Yahas, E<lt>gaal@forum2.orgE<gt> and others.

Please report any problems to the C<#perl6> channel on C<irc.freenode.org>.

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2005, 2006 by Gaal Yahas

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.7 or,
at your option, any later version of Perl 5 you may have available.


=cut
